import typer
import os
import os.path
import twine
import requests


app = typer.Typer()

@app.command()
def publish():

    typer.echo("Eating your files...")
    os.system('python setup.py bdist_wheel sdist')
    os.system('twine upload dist/*')

@app.command()
def create():
    url = "https://raw.githubusercontent.com/ssantoshp/StrategyLibraryQC/main/setup.py"
    response = requests.get(url)

    if os.path.isfile('setup.py'):
        answer = input("Should we replace your actual setup.py file? (y/n)")
        if answer == "y":
            os.remove('setup.py')
        else:
            print("Don't remove actual setup.py file...")
            pass
    else:
        with open('setup.py', 'a') as file:
            print(response.text, file=file)
        print("Just created the setup.py file!")


    url_readme = "https://gist.githubusercontent.com/DomPizzie/7a5ff55ffa9081f2de27c315f5018afc/raw/d59043abbb123089ad6602aba571121b71d91d7f/README-Template.md"
    response_readme = requests.get(url)

    if os.path.isfile('README.md'):
        answer = input("Should we replace your actual README.md file? (y/n)")
        if answer == "y":
            os.remove('README.md')

        else:
            print("Don't remove actual README.md file...")
            pass
    else:
            with open('README.md', 'a') as file:
                print(response_readme.text, file=file)
            print("Just created the README.md file!")

    os.mkdir("src")






# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['zeplyn']

package_data = \
{'': ['*']}

install_requires = \
['twine==3.4.1', 'typer[all]>=0.3.2,<0.4.0']

entry_points = \
{'console_scripts': ['zeplyn = zeplyn.zeplyn:app']}

setup_kwargs = {
    'name': 'zeplyn',
    'version': '0.1.1',
    'description': 'Zeplyn allows to you release python package fastly and easily in one command',
    'long_description': "# Zeplyn\n\n## Usage\n\nZeplyn allows to you release python package fastly and easily in one command: \n\n```zeplyn publish```\n\nYou should run that command in your command prompt in the folder directory where you want to put your package\n\nZeplyn also have a ```zeplyn create``` command which automatically create a readme file, a setup.py file and a src folder where your package's code is going to be stored.\n\nFull documentation here : https://github.com/ssantoshp/zeplyn",
    'author': 'ssantoshp',
    'author_email': 'santoshpassoubady@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
